@@ -101,7 +101,7 @@ bin_dots = function(x, y, binwidth,
     both = 0
   )
   switch(layout,
-    bin =, hex =, bar = {
+    bin = , hex = , bar = {
       bin_midpoints = h$binning$bin_midpoints
       if (overlaps == "nudge" && layout != "bar") {
         bin_midpoints = nudge_bins(bin_midpoints, binwidth, h$bin_counts)
@@ -132,9 +132,7 @@ bin_dots = function(x, y, binwidth,
       d$row = NULL
     },
     swarm = {
-      if (!requireNamespace("beeswarm", quietly = TRUE)) {
-        stop('Using layout = "swarm" with the dots geom requires the `beeswarm` package to be installed.') #nocov
-      }
+      stop_if_not_installed("beeswarm", '{.help geom_dots}(layout = "swarm")')
 
       swarm_xy = beeswarm::swarmy(d[[x]], d[[y]],
         xsize = h$binwidth, ysize = h$y_spacing,
@@ -251,22 +249,33 @@ find_dotplot_binwidth = function(
   layout = c("bin", "weave", "hex", "swarm", "bar")
 ) {
   layout = match.arg(layout)
-  x = sort(x, na.last = TRUE)
+  x = sort(as.numeric(x), na.last = TRUE)
 
   # figure out a reasonable minimum number of bins based on histogram binning
   min_nbins = if (length(x) <= 1) {
     1
-  } else{
+  } else {
     min(nclass.scott(x), nclass.FD(x), nclass.Sturges(x))
   }
   bin_method = select_bin_method(x, layout)
-  dot_heap_ = function(...) dot_heap(
-    x, ...,
-    maxheight = maxheight, heightratio = heightratio, stackratio = stackratio, bin_method = bin_method
-  )
+  dot_heap_ = function(...) {
+    dot_heap(
+      x,
+      ...,
+      maxheight = maxheight,
+      heightratio = heightratio,
+      stackratio = stackratio,
+      bin_method = bin_method
+    )
+  }
   min_h = dot_heap_(nbins = min_nbins)
 
-  if (!min_h$is_valid) {
+  if (min_h$is_valid) {
+    # if the minimum heap (i.e. the dot heap constructed from the smallest
+    # number of bins --- thus, at the upper limit of the height we will allow)
+    # is valid, then we don't need to search and can just use it.
+    h = min_h
+  } else {
     # figure out a maximum number of bins based on data resolution (except
     # for bars, which handle duplicate values differently, so must go by
     # number of data points instead of unique data points)
@@ -276,10 +285,7 @@ find_dotplot_binwidth = function(
       dot_heap_(binwidth = resolution(x))
     }
 
-    if (max_h$nbins <= min_h$nbins) {
-      # even at data resolution there aren't enough bins, not much we can do...
-      h = min_h
-    } else if (max_h$nbins == min_h$nbins + 1) {
+    if (max_h$nbins <= min_h$nbins + 1) {
       # nowhere to search, use maximum number of bins
       h = max_h
     } else {
@@ -328,20 +334,18 @@ find_dotplot_binwidth = function(
         h = new_h
       }
     }
-  } else {
-    h = min_h
   }
 
   # check if the selected heap spec is valid....
-  if (!h$is_valid_approx) {
+  if (h$is_valid_approx) {
+    h$max_binwidth
+  } else {
     # ... if it isn't, this means we've ended up with some bin that's too
     # tall, probably because we have discrete data --- we'll just
     # conservatively shrink things down so they fit by backing out a bin
     # width that works with the tallest bin
     y_spacing = maxheight / h$max_bin_count
     y_spacing / heightratio
-  } else {
-    h$max_binwidth
   }
 }
 
@@ -358,7 +362,15 @@ find_dotplot_binwidth = function(
 #' @param heightratio ratio between the bin width and the y spacing
 #' @return  a list of properties of this dot "heap"
 #' @noRd
-dot_heap = function(x, nbins = NULL, binwidth = NULL, maxheight = Inf, heightratio = 1, stackratio = 1, bin_method = automatic_bin) {
+dot_heap = function(
+  x,
+  nbins = NULL,
+  binwidth = NULL,
+  maxheight = Inf,
+  heightratio = 1,
+  stackratio = 1,
+  bin_method = automatic_bin
+) {
   xspread = diff(range(x))
   if (xspread == 0) xspread = 1
   if (is.null(binwidth)) {
@@ -621,7 +633,8 @@ select_bin_method = function(x, layout = "bin") {
 #' @noRd
 bar_bin = function(x, width, bar_scale = 0.9) {
   # determine the amount of space that each bar will take up
-  max_bar_width = resolution(x, zero = FALSE) * bar_scale
+  # TODO: can drop as.numeric here if https://github.com/tidyverse/ggplot2/issues/5709 is fixed
+  max_bar_width = resolution(as.numeric(x), zero = FALSE) * bar_scale
   n_bins = max(floor(max_bar_width / width), 1)
   actual_bar_width = n_bins * width
 
@@ -666,10 +679,10 @@ nudge_bins = function(bin_midpoints, width, count = rep(1, length(bin_midpoints)
   # equivalent to A = matrix(rep_len(c(-1, 1, rep(0, n - 1)), n * (n - 1)), nrow = n)
   # when using solve.QP()
   Amat = matrix(rep(c(-1, 1), n - 1), nrow = 2)
-  Aind = matrix(
-    c(rep(2, n - 1), seq_len(n - 1), seq(2, n)),
-    nrow = 3,
-    byrow = TRUE
+  Aind = rbind(
+    rep(2, n - 1),
+    seq_len(n - 1),
+    seq(2, n)
   )
   b = rep(width, n - 1)
 
