@@ -6,7 +6,7 @@
 
 # Names that should be suppressed from global variable check by codetools
 # Names used broadly should be put in _global_variables.R
-globalVariables(c(".width"))
+globalVariables(".width")
 
 
 #' @eval rd_slabinterval_shortcut_geom("pointinterval", "point + multiple-interval")
@@ -71,7 +71,8 @@ GeomPointinterval = ggproto("GeomPointinterval", GeomSlabinterval,
 
   hidden_params = union(c(
     "show_slab", "show_point", "show_interval",
-    "normalize", "fill_type"
+    "normalize", "fill_type",
+    "subguide"
   ), GeomSlabinterval$hidden_params),
 
   layer_args = defaults(list(
