@@ -48,7 +48,6 @@
 #'
 #' library(dplyr)
 #' library(ggplot2)
-#' library(forcats)
 #'
 #' theme_set(theme_ggdist())
 #'
@@ -56,9 +55,10 @@
 #'   eta = 1:6,
 #'   K = 2:6
 #' ) %>%
-#'   ggplot(aes(y = fct_rev(ordered(eta)), dist = "lkjcorr_marginal", arg1 = K, arg2 = eta)) +
+#'   ggplot(aes(y = ordered(eta), dist = "lkjcorr_marginal", arg1 = K, arg2 = eta)) +
 #'   stat_slab() +
 #'   facet_grid(~ paste0(K, "x", K)) +
+#'   scale_y_discrete(limits = rev) +
 #'   labs(
 #'     title = paste0(
 #'       "Marginal correlation for LKJ(eta) prior on different matrix sizes:\n",
@@ -106,7 +106,7 @@ rlkjcorr_marginal = function(n, K, eta) {
 #' @importFrom rlang is_integerish
 lkjcorr_marginal_alpha = function(K, eta) {
   if (!is_integerish(K) || K < 2) {
-    stop("Correlation matrix dimension (K) must be an integer greater than or equal to 2")
+    cli_abort("Correlation matrix dimension (K) must be an integer greater than or equal to 2")
   }
   eta - 1 + K/2
 }
@@ -142,8 +142,8 @@ lkjcorr_marginal_alpha = function(K, eta) {
 #' [parse_dist()].
 #' @param predicate a bare expression for selecting the rows of `data` to modify. This is useful
 #' if `data` contains more than one row with an LKJ prior in it and you only want to modify some
-#' of the distributions; if this is the case, give row a predicate expression (such as you might supply
-#' to [dplyr::filter()]) that evaluates to `TRUE` on the rows you want to modify.
+#' of the distributions; if this is the case, give row a predicate expression that evaluates to
+#' `TRUE` on the rows you want to modify.
 #' If `NULL` (the default), all `lkjcorr` distributions in `data` are modified.
 #' @param dist The name of the column containing distribution names. See [parse_dist()].
 #' @param args The name of the column containing distribution arguments. See [parse_dist()].
