@@ -6,7 +6,7 @@
 
 # scale_point_... ---------------------------------------------------------
 
-#' Custom ggplot scales for geom_slabinterval (and derivatives)
+#' Sub-geometry scales for geom_slabinterval (ggplot2 scales)
 #'
 #' These scales allow more specific aesthetic mappings to be made when using [geom_slabinterval()]
 #' and stats/geoms based on it (like eye plots).
@@ -66,7 +66,8 @@
 #' @return
 #' A [ggplot2::Scale] representing one of the aesthetics used to target the appearance of specific parts of composite
 #' `ggdist` geoms. Can be added to a [ggplot()] object.
-#' @name scales
+#' @name sub-geometry-scales
+#' @aliases scales
 #' @author Matthew Kay
 #' @family ggdist scales
 #' @seealso Other ggplot2 scales: [scale_color_discrete()], [scale_color_continuous()], etc.
@@ -104,110 +105,114 @@
 #' @export
 scale_point_colour_discrete =
   function(..., aesthetics = "point_colour") scale_colour_hue(..., aesthetics = aesthetics)
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_point_color_discrete = scale_point_colour_discrete
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_point_colour_continuous = function(..., aesthetics = "point_colour", guide = guide_colourbar2()) {
   scale_colour_continuous(..., aesthetics = aesthetics, guide = guide)
 }
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_point_color_continuous = scale_point_colour_continuous
 
 
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_point_fill_discrete =
   function(..., aesthetics = "point_fill") scale_colour_hue(..., aesthetics = aesthetics)
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_point_fill_continuous = function(..., aesthetics = "point_fill", guide = guide_colourbar2()) {
   scale_colour_continuous(..., aesthetics = aesthetics, guide = guide)
 }
 
 
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @importFrom scales rescale_pal
 #' @export
 scale_point_alpha_continuous = function(..., range = c(0.1, 1)) {
-  continuous_scale("point_alpha", "point_alpha_c", rescale_pal(range), ...)
+  continuous_scale("point_alpha", palette = rescale_pal(range), ...)
 }
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_point_alpha_discrete = function(..., range = c(0.1, 1)) {
-  discrete_scale("point_alpha", "point_alpha_d", function(n) seq(range[1], range[2], length.out = n), ...)
+  discrete_scale("point_alpha", palette = function(n) seq(range[1], range[2], length.out = n), ...)
 }
 
 
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @importFrom scales area_pal
 #' @export
 scale_point_size_continuous =
-  function(..., range = c(1, 6)) continuous_scale("point_size", "point_size_c", area_pal(range), ...)
-#' @rdname scales
+  function(..., range = c(1, 6)) continuous_scale("point_size", palette = area_pal(range), ...)
+#' @rdname sub-geometry-scales
 #' @export
 scale_point_size_discrete = function(..., range = c(1, 6), na.translate = FALSE) {
   force(range)
-  discrete_scale("point_size", "point_size_d", function(n) seq(range[1], range[2], length.out = n),
-    na.translate = na.translate, ...)
+  discrete_scale(
+    "point_size", palette = function(n) seq(range[1], range[2], length.out = n),
+    na.translate = na.translate, ...
+  )
 }
 
 
 # scale_interval_... ------------------------------------------------------
 
 #' @export
-#' @rdname scales
+#' @rdname sub-geometry-scales
 scale_interval_colour_discrete =
   function(..., aesthetics = "interval_colour") scale_colour_hue(..., aesthetics = aesthetics)
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_interval_color_discrete = scale_interval_colour_discrete
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_interval_colour_continuous = function(..., aesthetics = "interval_colour", guide = guide_colourbar2()) {
   scale_colour_continuous(..., aesthetics = aesthetics, guide = guide)
 }
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_interval_color_continuous = scale_interval_colour_continuous
 
 
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @importFrom scales rescale_pal
 #' @export
 scale_interval_alpha_continuous = function(..., range = c(0.1, 1)) {
-  continuous_scale("interval_alpha", "interval_alpha_c", rescale_pal(range), ...)
+  continuous_scale("interval_alpha", palette = rescale_pal(range), ...)
 }
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_interval_alpha_discrete = function(..., range = c(0.1, 1)) {
-  discrete_scale("interval_alpha", "interval_alpha_d", function(n) seq(range[1], range[2], length.out = n), ...)
+  discrete_scale("interval_alpha", palette = function(n) seq(range[1], range[2], length.out = n), ...)
 }
 
 
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @importFrom scales area_pal
 #' @export
 scale_interval_size_continuous =
-  function(..., range = c(1, 6)) continuous_scale("interval_size", "interval_size_c", area_pal(range), ...)
-#' @rdname scales
+  function(..., range = c(1, 6)) continuous_scale("interval_size", palette = area_pal(range), ...)
+#' @rdname sub-geometry-scales
 #' @export
 scale_interval_size_discrete = function(..., range = c(1, 6), na.translate = FALSE) {
   force(range)
-  discrete_scale("interval_size", "interval_size_d", function(n) seq(range[1], range[2], length.out = n),
-    na.translate = na.translate, ...)
+  discrete_scale(
+    "interval_size", palette = function(n) seq(range[1], range[2], length.out = n),
+    na.translate = na.translate, ...
+  )
 }
 
 
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @importFrom scales linetype_pal
 #' @export
 scale_interval_linetype_discrete = function(..., na.value = "blank") {
-  discrete_scale("interval_linetype", "interval_linetype_d", linetype_pal(), na.value = na.value, ...)
+  discrete_scale("interval_linetype", palette = linetype_pal(), na.value = na.value, ...)
 }
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_interval_linetype_continuous = function(...) {
   stop0("A continuous variable cannot be mapped to linetype")
@@ -217,103 +222,107 @@ scale_interval_linetype_continuous = function(...) {
 # scale_slab_... ----------------------------------------------------------
 
 #' @export
-#' @rdname scales
+#' @rdname sub-geometry-scales
 scale_slab_colour_discrete =
   function(..., aesthetics = "slab_colour") scale_colour_hue(..., aesthetics = aesthetics)
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_slab_color_discrete = scale_slab_colour_discrete
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_slab_colour_continuous = function(..., aesthetics = "slab_colour", guide = guide_colourbar2()) {
   scale_colour_continuous(..., aesthetics = aesthetics, guide = guide)
 }
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_slab_color_continuous = scale_slab_colour_continuous
 
 
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_slab_fill_discrete =
   function(..., aesthetics = "slab_fill") scale_colour_hue(..., aesthetics = aesthetics)
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_slab_fill_continuous = function(..., aesthetics = "slab_fill", guide = guide_colourbar2()) {
   scale_colour_continuous(..., aesthetics = aesthetics, guide = guide)
 }
 
 
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @importFrom scales rescale_pal
 #' @export
 scale_slab_alpha_continuous = function(..., limits = function(l) c(min(0, l[[1]]), l[[2]]), range = c(0, 1)) {
-  continuous_scale("slab_alpha", "slab_alpha_c", rescale_pal(range), limits = limits, ...)
+  continuous_scale("slab_alpha", palette = rescale_pal(range), limits = limits, ...)
 }
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_slab_alpha_discrete = function(..., range = c(0.1, 1)) {
-  discrete_scale("slab_alpha", "slab_alpha_d", function(n) seq(range[1], range[2], length.out = n), ...)
+  discrete_scale("slab_alpha", palette = function(n) seq(range[1], range[2], length.out = n), ...)
 }
 
 
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @importFrom scales rescale_pal
 #' @export
 scale_slab_size_continuous =
-  function(..., range = c(1, 6)) continuous_scale("slab_size", "slab_size_c", rescale_pal(range), ...)
-#' @rdname scales
+  function(..., range = c(1, 6)) continuous_scale("slab_size", palette = rescale_pal(range), ...)
+#' @rdname sub-geometry-scales
 #' @export
 scale_slab_size_discrete = function(..., range = c(1, 6), na.translate = FALSE) {
   force(range)
-  discrete_scale("slab_size", "slab_size_d", function(n) seq(range[1], range[2], length.out = n),
-    na.translate = na.translate, ...)
+  discrete_scale(
+    "slab_size", palette = function(n) seq(range[1], range[2], length.out = n),
+    na.translate = na.translate, ...
+  )
 }
 
 
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @importFrom scales rescale_pal
 #' @export
 scale_slab_linewidth_continuous =
-  function(..., range = c(1, 6)) continuous_scale("slab_linewidth", "slab_linewidth_c", rescale_pal(range), ...)
-#' @rdname scales
+  function(..., range = c(1, 6)) continuous_scale("slab_linewidth", palette = rescale_pal(range), ...)
+#' @rdname sub-geometry-scales
 #' @export
 scale_slab_linewidth_discrete = function(..., range = c(1, 6), na.translate = FALSE) {
   force(range)
-  discrete_scale("slab_linewidth", "slab_linewidth_d", function(n) seq(range[1], range[2], length.out = n),
-    na.translate = na.translate, ...)
+  discrete_scale(
+    "slab_linewidth", palette = function(n) seq(range[1], range[2], length.out = n),
+    na.translate = na.translate, ...
+  )
 }
 
 
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @importFrom scales linetype_pal
 #' @export
 scale_slab_linetype_discrete = function(..., na.value = "blank") {
-  discrete_scale("slab_linetype", "slab_linetype_d", linetype_pal(), na.value = na.value, ...)
+  discrete_scale("slab_linetype", palette = linetype_pal(), na.value = na.value, ...)
 }
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 scale_slab_linetype_continuous = function(...) {
   stop0("A continuous variable cannot be mapped to linetype")
 }
 
 
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @importFrom scales shape_pal
 #' @export
 scale_slab_shape_discrete = function(..., solid = TRUE) {
-  discrete_scale("slab_shape", "slab_shape_d", shape_pal(solid), ...)
+  discrete_scale("slab_shape", palette = shape_pal(solid), ...)
 }
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
-scale_slab_shape_continuous = function (...) {
+scale_slab_shape_continuous = function(...) {
   stop0("A continuous variable cannot be mapped to shape")
 }
 
 
 # guide_colorbar2 ---------------------------------------------------------
 
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 guide_colourbar2 = function(...) {
   # the default colourbar throws an error when asked to draw color bars for these aesthetics
@@ -327,6 +336,6 @@ guide_colourbar2 = function(...) {
   )))
 }
 
-#' @rdname scales
+#' @rdname sub-geometry-scales
 #' @export
 guide_colorbar2 = guide_colourbar2
