@@ -7,12 +7,14 @@
 
 # shared scale ------------------------------------------------------------
 
-#' Scale for slab thickness
+#' Slab thickness scale (ggplot2 scale)
 #'
 #' This \pkg{ggplot2} scale linearly scales all `thickness` values of geoms
 #' that support the `thickness` aesthetic (such as [geom_slabinterval()]). It
 #' can be used to align the `thickness` scales across multiple geoms (by default,
 #' `thickness` is normalized on a per-geom level instead of as a global scale).
+#' For a comprehensive discussion and examples of slab scaling and normalization,
+#' see the [`thickness` scale article](https://mjskay.github.io/ggdist/articles/thickness.html).
 #'
 #' @inheritParams ggplot2::continuous_scale
 #' @inheritDotParams ggplot2::continuous_scale
@@ -22,8 +24,9 @@
 #' is in use, the geom-specific `normalize` parameter is ignored (this is achieved
 #' by flagging values as already normalized by wrapping them in `thickness()`).
 #' Set this to `TRUE` to allow geoms to also apply their own normalization.
-#' @param x An object (typically a `numeric()`) to be converted to a `thickness()`
-#' object.
+#' Note that if you set renormalize to `TRUE`, subguides created via the
+#' `subguide` parameter to [geom_slabinterval()] will display the scaled values
+#' output by this scale, not the original data values.
 #' @details
 #' By default, normalization/scaling of slab thicknesses is controlled by geometries,
 #' not by a \pkg{ggplot2} scale function. This allows various functionality not
@@ -102,11 +105,12 @@ scale_thickness_shared = function(
   ...
 ) {
   sc = continuous_scale(
-    "thickness", "thickness_c", identity_pal(),
+    "thickness", palette = identity_pal(),
     name = name, breaks = breaks, labels = labels,
     limits = limits,
     oob = oob,
     guide = guide,
+    expand = expansion(0, 0),
     ...,
     super = ScaleThicknessShared
   )
@@ -127,7 +131,7 @@ ScaleThicknessShared = ggproto("ScaleThicknessShared", ScaleContinuous,
     if (self$renormalize) {
       out
     } else {
-      as_thickness(out)
+      thickness(out, limits[[1]], limits[[2]])
     }
   },
 
@@ -144,9 +148,9 @@ ScaleThicknessShared = ggproto("ScaleThicknessShared", ScaleContinuous,
 #' @rdname scale_thickness
 #' @importFrom scales identity_pal
 #' @export
-scale_thickness_identity = function (..., guide = "none") {
+scale_thickness_identity = function(..., guide = "none") {
   continuous_scale(
-    "thickness", "identity", identity_pal(),
+    "thickness", palette = identity_pal(),
     ...,
     guide = guide, super = ScaleContinuousIdentity
   )
@@ -163,16 +167,36 @@ scale_type.ggdist_thickness = function(x) {
 
 # data type for thickness ---------------------------------------------------------------
 
-new_thickness = function(x = double()) {
+new_thickness = function(x = double(), lower = NA_real_, upper = NA_real_) {
+  if (length(x) < 1) x = double()
   stopifnot(is.double(x))
-  new_vctr(x, class = "ggdist_thickness")
+  if (length(lower) <= 1) lower = rep(lower, length(x))
+  if (length(upper) <= 1) upper = rep(upper, length(x))
+  new_rcrd(list(x = x, lower = lower, upper = upper), class = "ggdist_thickness")
 }
 
 #' @rdname scale_thickness
+#' @param x An object (typically a `numeric()`) to be converted to a `thickness()`
+#' object.
+#' @param lower The original lower bounds of thickness values before scaling.
+#' @param upper The original upper bounds of thickness values before scaling.
 #' @export
-thickness = function(x = double()) {
+thickness = function(x = double(), lower = NA_real_, upper = NA_real_) {
   x = vec_cast(x, double())
-  new_thickness(x)
+  lower = vec_cast(lower, double())
+  upper = vec_cast(upper, double())
+  new_thickness(x, lower, upper)
+}
+
+
+# bounds ------------------------------------------------------------------
+
+thickness_lower = function(x) {
+  if (is_thickness(x)) field(x, "lower") else NA
+}
+
+thickness_upper = function(x) {
+  if (is_thickness(x)) field(x, "upper") else NA
 }
 
 
@@ -182,6 +206,11 @@ is_thickness = function(x) {
   inherits(x, "ggdist_thickness")
 }
 
+#' @export
+is.na.ggdist_thickness = function(x) {
+  is.na(field(x, "x"))
+}
+
 
 # formatting ------------------------------------------------------
 
@@ -192,7 +221,7 @@ vec_ptype_abbr.ggdist_thickness = function(x, ...) "thk"
 
 #' @export
 format.ggdist_thickness = function(x, ...) {
-  sprintf("%sthk", vec_data(x))
+  sprintf("%sthk [%s,%s]", field(x, "x"), field(x, "lower"), field(x, "upper"))
 }
 
 
@@ -214,12 +243,14 @@ vec_ptype2.ggdist_thickness.integer = function(x, y, ...) new_thickness()
 #' @export
 vec_ptype2.integer.ggdist_thickness = function(x, y, ...) new_thickness()
 
-#' @export
-vec_cast.double.ggdist_thickness = function(x, to, ...) vec_data(x)
 #' @export
 vec_cast.ggdist_thickness.double = function(x, to, ...) thickness(x)
 #' @export
 vec_cast.ggdist_thickness.integer = function(x, to, ...) thickness(x)
+#' @export
+vec_cast.double.ggdist_thickness = function(x, to, ...) field(x, "x")
+#' @export
+vec_cast.integer.ggdist_thickness = function(x, to, ...) as.integer(field(x, "x"))
 
 
 # arithmetic --------------------------------------------------------------
@@ -237,33 +268,56 @@ vec_arith.ggdist_thickness.default = function(op, x, y, ...) {
 
 #' @export
 #' @method vec_arith.ggdist_thickness ggdist_thickness
-vec_arith.ggdist_thickness.ggdist_thickness <- function(op, x, y, ...) {
+vec_arith.ggdist_thickness.ggdist_thickness = function(op, x, y, ...) {
+  x_value = field(x, "x")
+  y_value = field(y, "x")
+
+  bounds = lapply(c(lower = "lower", upper = "upper"), function(bound) {
+    x_bound = field(x, bound)
+    y_bound = field(y, bound)
+    use_x = is.na(y_bound) | ((x_bound == y_bound) %in% TRUE)
+    use_y = is.na(x_bound)
+
+    incompatible = !(use_x | use_y)
+    if (any(incompatible)) {
+      cli_abort(
+        "incompatible <thickness> bounds at locations {which(incompatible)}",
+        class = "ggdist_incompatible_thickness_bounds"
+      )
+    }
+
+    x_bound[use_y] = y_bound[use_y]
+    x_bound
+  })
+
   switch(
     op,
     "+" = ,
-    "-" = new_thickness(vec_arith_base(op, x, y)),
-    "/" = vec_arith_base(op, x, y),
+    "-" = new_thickness(vec_arith_base(op, x_value, y_value), bounds$lower, bounds$upper),
+    "/" = vec_arith_base(op, x_value, y_value),
     stop_incompatible_op(op, x, y)
   )
 }
 
 #' @export
 #' @method vec_arith.ggdist_thickness numeric
-vec_arith.ggdist_thickness.numeric <- function(op, x, y, ...) {
+vec_arith.ggdist_thickness.numeric = function(op, x, y, ...) {
+  x_value = field(x, "x")
   switch(
     op,
     "/" = ,
-    "*" = new_thickness(vec_arith_base(op, x, y)),
+    "*" = new_thickness(vec_arith_base(op, x_value, y), field(x, "lower"), field(x, "upper")),
     stop_incompatible_op(op, x, y)
   )
 }
 
 #' @export
 #' @method vec_arith.numeric ggdist_thickness
-vec_arith.numeric.ggdist_thickness <- function(op, x, y, ...) {
+vec_arith.numeric.ggdist_thickness = function(op, x, y, ...) {
+  y_value = field(y, "x")
   switch(
     op,
-    "*" = new_thickness(vec_arith_base(op, x, y)),
+    "*" = new_thickness(vec_arith_base(op, x, y_value), field(y, "lower"), field(y, "upper")),
     stop_incompatible_op(op, x, y)
   )
 }
