@@ -7,7 +7,7 @@ library(dplyr)
 library(coda)
 
 # raw RankCorr mcmc.list
-raw = readRDS("data-raw/RankCorr.rds")
+raw = readRDS(file.path("data-raw", "RankCorr.rds"))
 
 # variable names to subset the chains to
 var_names = grepl("(b\\[[1-3],[1-4]\\])|tau\\[[1-3]\\]|typical_r", dimnames(raw[[1]])[[2]])
