@@ -28,6 +28,23 @@ test_that("distribution functions work on wrapped distributions", {
 })
 
 
+# weighted sample distributions -------------------------------------------
+
+test_that("distribution functions work on weighted sample distributions", {
+  x = .dist_weighted_sample(list(qnorm(ppoints(20000), mean = c(1,5), c(1,2))), list(rep(c(1,3), 10000)))
+  ref = dist_mixture(dist_normal(1,1), dist_normal(5,2), weights = c(1,3)/4)
+  eps = 0.005
+  expect_equal(mean(x), mean(ref), tolerance = eps)
+  expect_equal(median(x), median(ref), tolerance = eps)
+  expect_equal(Mode(x), 5, tolerance = 0.01)
+  expect_equal(variance(x), variance(ref), tolerance = eps)
+  expect_equal(distr_pdf(x)(2), distr_pdf(ref)(2), tolerance = eps)
+  expect_equal(distr_cdf(x)(1), distr_cdf(ref)(1), tolerance = eps)
+  expect_equal(distr_quantile(x)(0.5), distr_quantile(ref)(0.5), tolerance = eps)
+  expect_equal(format(x), "weighted_sample[20000]")
+})
+
+
 # distributional objects --------------------------------------------------
 
 test_that("distribution functions work on distributional objects", {
@@ -105,14 +122,13 @@ test_that("distribution functions work on factor rvars", {
 
   expect_equal(
     distr_point_interval(x_ordered, median_qi, trans = scales::identity_trans()),
-    data.frame(
+    tibble(
       .value = 2,
       .lower = 1,
       .upper = 3,
       .width = 0.95,
       .point = "median",
-      .interval = "qi",
-      stringsAsFactors = FALSE
+      .interval = "qi"
     )
   )
 })
