@@ -4,7 +4,6 @@
 ###############################################################################
 
 library(dplyr)
-library(purrr)
 library(tidyr)
 
 
@@ -30,7 +29,10 @@ test_that("horizontal grouped pointintervals work", {
   vdiffr::expect_doppelganger("grouped pointintervals (h, stat)",
     RankCorr_u_tau %>%
       ggplot(aes(y = factor(i), x = u_tau)) +
-      stat_pointinterval(.width = c(.66, .95))
+      stat_pointinterval(
+        .width = c(.66, .95),
+        arrow = arrow(angle = 45, length = unit(4, "pt"), type = "closed", ends = "both")
+      )
   )
 
   vdiffr::expect_doppelganger("grouped pointintervals (h, reverse order)",
@@ -60,8 +62,11 @@ test_that("grouped pointintervals work", {
 
   forward_plot = RankCorr_u_tau %>%
     mean_qi(.width = c(.66, .95)) %>%
-    ggplot(aes(x = i, y = u_tau, ymin = .lower, ymax = .upper, interval_size = forcats::fct_rev(ordered(.width))), point_size = 3) +
-    geom_pointinterval()
+    ggplot(aes(
+      x = i, y = u_tau, ymin = .lower, ymax = .upper,
+      interval_size = fct_rev_(ordered(.width))
+    )) +
+    geom_pointinterval(point_size = 3)
 
   vdiffr::expect_doppelganger("grouped, with interval_size and legend", forward_plot)
 
@@ -77,12 +82,13 @@ test_that("orientation detection on pointintervals works", {
   skip_if_no_vdiffr()
 
 
-  p = data.frame(
-    v = c(1,2),
+  p = tibble(
+    v = c(1, 2),
     l = c(0, 1),
-    u = c(4,5),
+    u = c(4, 5),
     g = c("a", "b")
-  ) %>% ggplot()
+  ) %>%
+    ggplot()
 
   vdiffr::expect_doppelganger("vertical, orientation detection",
     p + geom_pointinterval(aes(x = g, y = v, ymin = l, ymax = u), orientation = NA)
@@ -106,16 +112,20 @@ test_that("missing data is handled correctly", {
   skip_if_no_vdiffr()
 
 
-  p = data.frame(
+  p = tibble(
     x = c(1,NA,1),
     xmin = c(NA,0,0),
     xmax = c(NA,2,2),
     y = c("a","b",NA)
-  ) %>% ggplot(aes(x=x,xmin=xmin,xmax=xmax, y=y))
+  ) %>%
+    ggplot(aes(x = x, xmin = xmin, xmax = xmax, y = y))
 
-  expect_warning(vdiffr::expect_doppelganger("geom_pointinterval na.rm = FALSE",
-    p + geom_pointinterval(na.rm = FALSE)
-  ), "Removed 1 rows containing\\s+missing values")
+  expect_warning(
+    vdiffr::expect_doppelganger("geom_pointinterval na.rm = FALSE",
+      p + geom_pointinterval(na.rm = FALSE)
+    ),
+    "Removed 1 row.+missing values"
+  )
 
   vdiffr::expect_doppelganger("geom_pointinterval na.rm = TRUE",
     p + geom_pointinterval(na.rm = TRUE)
