@@ -5,7 +5,6 @@
 
 library(dplyr)
 library(tidyr)
-library(purrr)
 library(distributional)
 
 
@@ -32,11 +31,11 @@ test_that("rampbar works with fill_ramp", {
 test_that("rampbar works with color_ramp", {
   skip_if_no_vdiffr()
 
-  vdiffr::expect_doppelganger("color_ramp without `to`",
+  vdiffr::expect_doppelganger("reversed color_ramp without `to`",
     tibble(d = dist_uniform(0, 1)) %>%
       ggplot(aes(y = 0, dist = d)) +
       stat_dist_slab(aes(color_ramp = after_stat(x)), n = 20, color = "red", size = 5) +
-      scale_color_ramp_continuous(from = "blue", guide = guide_rampbar())
+      scale_color_ramp_continuous(from = "blue", guide = guide_rampbar(reverse = TRUE))
   )
 
   vdiffr::expect_doppelganger("color_ramp with `to`",
