@@ -15,11 +15,10 @@ test_that("ggmcmc translators work", {
     dplyr::rename(.variable = i, .value = u_tau) %>%
     group_by(.variable)
 
-  result = orig %>%
-    to_ggmcmc_names()
+  result = to_ggmcmc_names(orig)
 
-  expect_equal(names(result), c("Parameter", "value", "Chain", "Iteration", ".draw"))
-  expect_equal(group_vars(result), "Parameter")
+  expect_named(result, c("Parameter", "value", "Chain", "Iteration", ".draw"))
+  expect_equal(dplyr::group_vars(result), "Parameter")
   expect_equal(from_ggmcmc_names(result), orig)
 })
 
@@ -29,11 +28,12 @@ test_that("broom translators work", {
   orig = RankCorr_u_tau %>%
     dplyr::rename(.variable = i, .value = u_tau) %>%
     group_by(.variable) %>%
-    median_qi(.value)
+    median_qi(.value) %>%
+    group_by(.variable)
 
-  result = orig %>%
-    to_broom_names()
+  result = to_broom_names(orig)
 
-  expect_equal(names(result), c("term", "estimate", "conf.low", "conf.high", ".width", ".point", ".interval"))
+  expect_named(result, c("term", "estimate", "conf.low", "conf.high", ".width", ".point", ".interval"))
+  expect_equal(dplyr::group_vars(result), "term")
   expect_equal(from_broom_names(result), orig)
 })
